@@ -1,10 +1,12 @@
+# Paul Glenn
+# curves.py
 # Give curve pairs class structure in preparation for public access
 import numpy as np
-from itertools import product, izip
+from itertools import product
 from copy import deepcopy
-import re
 
-def fix_matrix_signs(M):
+
+def fixMatrixSigns(M):
     '''
     :param M: The matrix with incorrect signs.
     :type M: numpy.array(dtype=float64) of shape (2,n,4)
@@ -18,33 +20,32 @@ def fix_matrix_signs(M):
 
     '''
 
-    row, col = [-1, 1]
+    row, col = [-1,1]
     sgn = 1
     #for ii in range(len(M[0,:])):
-    while 0 in M[1, :, 1:4:2] and row < M.shape[1]-1:
+    while 0 in M[1,:,1:4:2] and row < M.shape[1]-1:
         row += 1
         sgn = -sgn
         # Starting position and sign are arbitrary.
         for i in range(M.shape[1]):
-            g_val = int(M[0, row, col])
-            new = np.array(np.where(M[0, g_val, :] == row))
+            gval = int(M[0,row,col])
+            new = np.array( np.where(M[0,gval,:]==row) )
             #print  np.where(new%2==col%2)
-            ind = int(new[np.where(new % 2 == col % 2)])
+            ind = int( new[ np.where(new%2==col%2)] )
             sgn = -sgn
-            M[1, g_val, ind] = sgn
+            M[1,gval,ind] = sgn
             ind += 2
             ind = ind % M.shape[2]
             sgn = -sgn
-            M[1, g_val, ind] = sgn
-            row = g_val
+            M[1,gval,ind] = sgn
+            row = gval
             col = ind
-        M[1, :, 0] = -1
-        M[1, :, 2] = 1
+        M[1,:,0] = -1
+        M[1,:,2] = 1
     return M
 
 
-
-def concatenate_matrix(M1, M2):
+def concatenateMatrix(M1, M2):
     '''
     :param M1: First matrix to combine
     :type M1: numpy.array(dtype=float64) of shape (2,n,4)
@@ -59,61 +60,59 @@ def concatenate_matrix(M1, M2):
     INV: final matrix will correspond to a single curve.
 
     '''
-    top_M = np.copy(M1)
-    bot_m = np.copy(M2)
+    topM = np.copy(M1)
+    botM = np.copy(M2)
     n = M1.shape[1]
     m = M2.shape[1]
-    top_M[0, 0, 0] = n + m - 1
-    top_M[0, n-1, 2] = n
-    bot_m[0] += n * np.ones(M2[0].shape)
-    bot_m[0, m-1, 2] = 0
-    bot_m[0, 0, 0] = n-1
-    new_M = np.vstack((top_M[0], bot_m[0]))  # Multi-curve
-    new_M = np.vstack((new_M, np.vstack((top_M[1], bot_m[1])))).reshape((2, n+m, 4))
+    topM[0,0,0] = n + m - 1
+    topM[0,n-1,2] = n
+    botM[0] += n * np.ones(M2[0].shape)
+    botM[0,m-1,2] = 0
+    botM[0,0,0] = n-1
+    newM = np.vstack((topM[0], botM[0])) #  Multi-curve
+    newM = np.vstack((newM, np.vstack((topM[1], botM[1])) )).reshape((2,n+m,4))
 
-    left = zip(np.where(top_M[0] == n-1)[0], np.where(top_M[0] == n-1)[1])
+    left = zip(np.where(topM[0] == n-1)[0], np.where(topM[0] == n-1)[1])
     i0, j0 = 0,0
     for pair in left:
         i, j = pair
-        if j % 2 == 1:
-            i0, j0 = i, j
-    new_M[0, i0, j0] = n
+        if j%2 == 1: i0,j0 = i,j
+    newM[0,i0,j0] = n
 
-    temp_ind = np.where(new_M[0, n-1, :] == i0)[0]
-    temp_ind = int(temp_ind[temp_ind % 2 == 1][0])
-    temp_val = new_M[0, n-1, temp_ind]
-    switch_val = new_M[0, n, temp_ind]
-    new_M[0, n-1, temp_ind] = switch_val
-    new_M[0, n, temp_ind] = temp_val
-    return_ind = new_M[0, switch_val, :] == n
-    return_ind[0:3:2] = False
-    new_M[0, switch_val, return_ind == True] = n-1
+    tempInd = np.where(newM[0,n-1,:] == i0)[0]
+    tempInd = int(tempInd[tempInd%2==1][0])
+    tempVal = newM[0, n-1, tempInd]
+    switchVal = newM[0, n, tempInd]
+    newM[0, n-1, tempInd] = switchVal
+    newM[0,n,tempInd] = tempVal
+    returnInd = newM[0,switchVal,:] == n
+    returnInd[0:3:2] = False
+    newM[0,switchVal,returnInd==True] = n-1
 
-    return fix_matrix_signs(new_M)
+    return fixMatrixSigns(newM)
 
 ## Path finding methods -- used to find edge paths in the complement of beta-curve.
 ## Most are helpers for findAllPaths below.
-
-
-
-def visited(curr, face, path):
-    """
-
+def visited(curr, face , path):
+    '''
     :param curr:
+    :type curr:
     :param face:
+    :type face:
     :param path:
-    :return:
-    """
-    my_face = list(face)
-    my_face.remove(curr)
+    :type path:
+
+
+    '''
+
+    myface = list(face)
+    myface.remove(curr)
     v = 0
-    for edge in my_face:
-        if edge in path:
-            v = 1
+    for edge in myface:
+        if edge in path: v = 1
     return v
 
-
-def is_unique(path, all_paths):
+def isUnique(path, AllPaths):
     '''
     :param path:
     :type path:
@@ -122,8 +121,7 @@ def is_unique(path, all_paths):
     :returns: boolean
 
     '''
-    return not (path in all_paths)
-
+    return not ( path in AllPaths)
 
 def shift(path):
     '''
@@ -134,11 +132,11 @@ def shift(path):
     :type path: list
     :returns: list with intersections shifted in order such that the lowest intersection is in the first position.
 
+
     '''
     temp = path.index(min(path))
     return path[temp:] + path[:temp]
 
-
 def invert(path):
     '''
     :param path: some path
@@ -148,8 +146,7 @@ def invert(path):
     '''
     return shift(path[::-1])
 
-
-def path_finished_single(edge, face, path):
+def pathFinishedSingle(edge, face, path):
     '''
     :param edge:
     :type edge:
@@ -160,15 +157,14 @@ def path_finished_single(edge, face, path):
     :returns:
 
     '''
-    C = len(path) > 2 and (edge == path[-1])
+    C  = len(path)>2 and (edge == path[-1])
     faceL = list(face)
     faceL.remove(edge)
     C = C and not set(faceL).isdisjoint(set(path))
     #meeting = lambda e1, e2, face: e1 in face and e2 in face
     return C
 
-
-def path_finished_double(edge, face, path):
+def pathFinishedDouble(edge, face, path):
     '''
     :param edge:
     :type edge:
@@ -180,90 +176,85 @@ def path_finished_double(edge, face, path):
 
     '''
 
-    C = len(path) > 2 and (edge == path[-1])
+    C  = len(path)>2 and (edge == path[-1])
     faceL = list(face)
     faceL.remove(edge)
     C = C and not set(faceL).isdisjoint(set(path))
-    if path.count(edge) != 2 :
-        C = 0
+    if path.count(edge) != 2 : C = 0
     #meeting = lambda e1, e2, face: e1 in face and e2 in face
     return C
 
-
-
-def find_new_paths(current_path, my_face, faces, all_paths, path_function):
+def findNewPaths(currentPath, myface, faces, AllPaths, pathFunction):
     '''
-    :param current_path:
-    :type current_path:
-    :param my_face:
-    :type my_face:
+    :param currentPath:
+    :type currentPath:
+    :param myface:
+    :type myface:
     :param faces:
     :type faces:
-    :param all_paths:
-    :typeall_pathss:
-    :param path_function:
-    :typepath_functionn:
+    :param AllPaths:
+    :type AllPaths:
+    :param pathFunction:
+    :type pathFunction:
     :returns:
 
     '''
 
-    start = current_path[0]
-    next_edge = None
-    sub_path = []
-    faces_without_current_face = list(faces)
-    faces_without_current_face.remove(my_face)
-    for face in faces: # Check all faces...
-        if start in face and face is not my_face:
-            #if we find the start edge in another face...
-            for other_face in faces_without_current_face:
-                #go through its edges...
-                if start in other_face: # needed?
-                    face_without_start = list(other_face)
-                    face_without_start.remove(start)
 
-                    for non_starting_edge in face_without_start:
+
+    start = currentPath[0]
+    nextEdge = None
+    subPath = []
+    facesWithoutCurrentFace = list(faces)
+    facesWithoutCurrentFace.remove(myface)
+    for face in faces: #Check all faces...
+        if start in face and face is not myface:
+            #if we find the start edge in another face...
+            for otherface in facesWithoutCurrentFace:
+                #go through its edges...
+                if start in otherface: # needed?
+                    faceWithoutStart = list(otherface)
+                    faceWithoutStart.remove(start)
+
+                    for nonStartingEdge in faceWithoutStart:
                         # try all edges in that path
-                        next_edge = non_starting_edge
-                        if  (not visited( start, other_face, current_path ) ) and\
-                            (next_edge not in my_face):
-                            sub_path = [next_edge]
-                            sub_path.extend(current_path)
+                        nextEdge = nonStartingEdge
+                        if  (not visited( start, otherface, currentPath ) ) and\
+                            (nextEdge not in myface):
+                            subPath = [nextEdge]
+                            subPath.extend(currentPath)
 
                             # Recursive call to take all possible directions
-                            find_new_paths(sub_path, other_face, faces, all_paths, path_function)
+                            findNewPaths(subPath, otherface, faces, AllPaths, pathFunction)
 
-                        elif path_function(next_edge, other_face, current_path):
-                            new_found_path = shift(current_path)
-                            inverted_path = invert(current_path)
-                            unique = lambda path: is_unique(path, all_paths)
-                            if unique(new_found_path) and unique(inverted_path):
-                                all_paths.append(new_found_path)
-                    face_without_start.append(start)
-        faces_without_current_face.append(face)
+                        elif pathFunction(nextEdge, otherface, currentPath):
+                            newFoundPath = shift(currentPath)
+                            invertedPath = invert(currentPath)
+                            unique = lambda path: isUnique(path, AllPaths)
+                            if unique(newFoundPath) and unique(invertedPath):
+                                AllPaths.append(newFoundPath)
+                    faceWithoutStart.append(start)
+        facesWithoutCurrentFace.append(face)
 
-
-def remove_duplicates(faces, all_paths):
+def removeDuplicates(faces, AllPaths):
     '''
     :param faces:
     :type faces:
-    :param all_paths:
-    :type all_paths:
+    :param AllPaths:
+    :type AllPaths:
     :returns:
 
     '''
-    paths = list(all_paths)
+    paths = list(AllPaths)
     for path in paths:
         for f in faces:
             counter = 0
             for e in f:
-                if e in path:
-                    counter += 1
-            if counter == 3:
-                all_paths.remove(path)
-    return all_paths
+                if e in path: counter += 1
+            if counter == 3: AllPaths.remove(path)
+    return AllPaths
 
-
-def find_all_paths(faces):
+def findAllPaths(faces):
     '''
     :param faces:
     :type faces:
@@ -271,121 +262,109 @@ def find_all_paths(faces):
 
     '''
 
-    all_paths = []
-    forward = lambda path, face, path_function: find_new_paths(path, face, faces, all_paths, path_function)
+    AllPaths = []
+    forward = lambda path, face, pathFunction: findNewPaths(path, face, faces, AllPaths, pathFunction)
     for face in faces:
         for edge in face:
-            forward([edge], face, path_finished_single)
+            forward([edge], face, pathFinishedSingle)
             #forward([edge], face, pathFinishedDouble)
-    all_paths = remove_duplicates(faces, all_paths)
-    return all_paths
+    AllPaths = removeDuplicates(faces,AllPaths)
+    return AllPaths
 
 ## Now that we have the paths, they need to be
 ## re- indexed so that matrices can be built from them.
-
-def build_matrices(edge_paths, all_paths):
+def buildMatrices(edgePaths, AllPaths):
     '''
-    :param edge_paths: list of face boundary orientations
-    :type edge_paths: list
-    :param all_paths: list
-    :type all_paths: list
+    :param edgePaths: list of face boundary orientations
+    :type edgePaths: list
+    :param AllPaths: list
+    :type AllPaths: list
 
     Take the paths in the skeleton of the complement of the transverse curve
     And create matrices.
     '''
     #print 'edgePaths:',edgePaths
     #print 'AllPaths:',AllPaths[0].loops
-    master_list = []
+    MasterList = []
 
     # Allow paths to be referenced by face
     #print edgePaths
+    for itr in range(len(edgePaths)):
+        edgePaths[itr] = dict(edgePaths[itr])
 
-    for itr in range(len(edge_paths)):
-        edge_paths[itr] = dict(edge_paths[itr])
-    #print 'all_paths:',all_paths
-    #print 'edge_paths:',edge_paths
-
-    ordered_paths , mapped_paths = [],[]
+    orderedPaths , mappedPaths = [],[]
 
     # Rescale path 0-len(path) for matrix
-    for path in all_paths:
-        ordered_path = list(np.sort(path))
-        ordered_paths.append(ordered_path)
-        mapped_paths.append(dict(zip(ordered_path,range(len(path)))))
-    #print mapped_paths,'\n'
+    for Path in AllPaths:
+        orderedPath = list(np.sort(Path))
+        orderedPaths.append(orderedPath)
+        mappedPaths.append(dict(zip(orderedPath,range(len(Path)))))
+
     #Create Matrices using details from edge paths.
-    for Path, mapped_path in zip(all_paths, mapped_paths):
+    for Path,mappedPath in zip(AllPaths,mappedPaths):
         #Value Matrix
-        path_size = len(Path)
-        shape = (path_size, 4)
+        pathSize = len(Path) ; shape =(pathSize,4)
         last = Path[len(Path)-1]
-        M = np.zeros(shape)
+        M = np.zeros(shape);
         M2 = np.zeros(shape)
-        M[:, 0] = np.array([path_size-1]+range(path_size-1))
-        M[:, 2] = np.array(range(1,path_size)+[0])
-        past_edges = dict()
-        future_edges = dict()
+        M[:,0] = np.array([pathSize-1]+range(pathSize-1))
+        M[:,2] = np.array(range(1,pathSize)+[0])
+        pastEdges = dict(); futureEdges =  dict()
         old_vertex = last
 
         itr = 1
         for vertex in Path:
             flag = False
-            for path in edge_paths:
-                keys = set(path.keys())
+            for path in edgePaths:
+                keys = path.keys()
                 if vertex in keys and old_vertex in keys:
-                    past_edges[vertex] = path[vertex]
+                    pastEdges[vertex] = path[vertex]
                     flag = True
-                if vertex in keys and Path[itr % path_size] in keys:
+                if vertex in keys and Path[itr%pathSize] in keys:
                     if flag:
-                        future_edges[vertex] = (path[vertex] + 2) % 4
+                        futureEdges[vertex] = (path[vertex]+ 2) %4
                     else:
-                        future_edges[vertex] = path[vertex]
-                flag = False
+                        futureEdges[vertex] = path[vertex]
+                flag =False
             old_vertex = vertex
             itr += 1
-        old_vertex = last
+        old_vertex = last;
 
         itr = 1
         for vertex in Path:
             curr_vertex = vertex
-            next_vertex = Path[itr % path_size]
-            M[mapped_path[vertex], past_edges[vertex]] = mapped_path[old_vertex]
-            M[mapped_path[vertex], future_edges[vertex]] = mapped_path[next_vertex]
+            next_vertex = Path[itr%pathSize]
+            M[mappedPath[vertex],pastEdges[vertex]] = mappedPath[old_vertex]
+            M[mappedPath[vertex],futureEdges[vertex]] = mappedPath[next_vertex]
             old_vertex = curr_vertex
             itr += 1
 
         # Sign matrix: Stand-alone function
-        M = fix_matrix_signs(np.array([M, M2], dtype=int))
-        master_list.append(M)
+        M = fixMatrixSigns(np.array([M, M2], dtype=int))
+        MasterList.append(M)
     # End while
 
-    return master_list
+    return MasterList
 
-
-
-def face_parse(alpha_edges):
+def faceParse(alphaEdges):
     '''
-    :param alpha_edges: set of faces with alpha edges.
-    :typealpha_edgess:
+    :param alphaEdges: set of faces with alpha edges.
+    :type alphaEdges:
     :returns: (Bridges, Isalnds, lengthCheck) Bridges : 4-sided regions; Islands : n > 4 - gons; lengthCheck : the number of alpha edges included.
 
     Separate set of all faces into bridges (4-sided regions) and
     islands (higher-sided regions) for distance calculator.
 
     '''
-    bridges, islands = [], []
-    length_check = []
-    for pair in alpha_edges:
-        if pair[0] == 4:
-            bridges.append(pair)
-        else:
-            islands.append(pair)
-        length_check.extend(list(pair[1]))
-    return bridges, islands, len(length_check)
+    Bridges, Islands = [],[]
+    lengthCheck = []
+    for pair in alphaEdges:
+        if pair[0] == 4: Bridges.append(pair)
+        else: Islands.append(pair)
+        lengthCheck.extend(list(pair[1]))
+    return Bridges, Islands, len(lengthCheck)
 
 ######					For Distance Extension 					#######
-
-
 def connected(P1, P2):
     '''
     :param P1:
@@ -396,15 +375,13 @@ def connected(P1, P2):
 
     '''
 
-    S1 = set(P1)
+    S1  = set(P1)
     S2 = set(P2)
-    if S1.isdisjoint(S2) or (S1.issubset(S2) and S1.issuperset(S2)):
-        return 0
-    else:
-        return 1
+    if S1.isdisjoint(S2): return 0
+    elif S1.issubset(S2) and S1.issuperset(S2): return 0
+    return 1
 
-
-def share_edge(path1, path2):
+def shareEdge(path1, path2):
     '''
     :param path1:
     :type path1:
@@ -413,42 +390,40 @@ def share_edge(path1, path2):
     :returns:
 
     '''
-    if not set(path1).isdisjoint(path2):
-        return 0, -1
+    share = 0
+    if not set(path1).isdisjoint(path2): share = 1
+    if share == 0: return 0, -1
     else:
-        intersection_set = set(path1) & set(path2)
-        numshared = len(intersection_set)
-        if numshared != 1:
-            return 0, -1 #Then they share too much!
+        intersectionSet = set(path1) & set(path2)
+        numshared = len(intersectionSet)
+        if numshared != 1: return 0, -1 #Then they share too much!
         else:
-            shared_item = intersection_set.pop()
-    return 1, path2.index(shared_item)
+            sharedItem = intersectionSet.pop()
+    return 1,path2.index(sharedItem)
 
-
-def find_combined_paths(all_paths, M_library):
+def findCombinedPaths( allPaths, MLibrary):
     '''
-    :param all_paths:
-    :typeall_pathss:
-    :param M_library:
-    :typeM_libraryy:
+    :param allPaths:
+    :type allPaths:
+    :param MLibrary:
+    :type MLibrary:
     :returns:
     '''
-    list_of_connected = []
-    path_library = dict(zip(range(len(all_paths)), all_paths))
+    ListofConnected = []
+    pathLibrary = dict(zip(range(len(allPaths)),allPaths))
     index1 = 0
-    for path1 in all_paths:
+    for path1 in allPaths:
         index2 = 0
-        for path2 in all_paths:
-            if share_edge(path1, path2)[0]:
-                list_of_connected.append((M_library[index1],
-                            M_library[index2]))
+        for path2 in allPaths:
+            if shareEdge(path1, path2)[0]:
+                ListofConnected.append((MLibrary[index1],
+                            MLibrary[index2]))
             index2 += 1
         index1 += 1
 
-    return list_of_connected
+    return ListofConnected
 
-
-def faces_share_two_edges(faces):
+def facesShareTwoEdges(faces):
     '''
     :param faces:
     :type faces:
@@ -456,17 +431,15 @@ def faces_share_two_edges(faces):
 
     '''
 
-    distance_three_flag = 0
+    distanceThreeFlag = 0
 
     for face in faces:
-        faces_without_face = list(faces)
-        faces_without_face.remove(face)
-        for other in faces_without_face:
-            if len(set(face) & set(other)) >1: distance_three_flag = 1
-
-    return distance_three_flag
-
+        facesWithoutFace = list(faces)
+        facesWithoutFace.remove(face)
+        for other in facesWithoutFace:
+            if len(set(face) & set(other)) >1: distanceThreeFlag = 1
 
+    return distanceThreeFlag
 
 def edges(M):
     '''
@@ -476,23 +449,22 @@ def edges(M):
     '''
     #print 'called edges'
     # The em list is needed to hold the tuples of (faceLength, faceEdges)
-    all_faces = []
+    allFaces = [ ]
     # INV: Number of faces found.
-    faces = 0
+    faces = 0 ;
 
-    num_rows, num_cols = M.shape[1:3] #num_rows, num_cols
+    numrows, numcols = M.shape[1:3] #num_rows, num_cols
 
-    old_vertices = [] ##list of previous paths
+    old_Vertices = [ ] ##list of previous paths
     bigonFlag = 0
     # Bigons are unwanted structures.
-    Paths = []  # alpha - edge paths.
+    Paths = [ ]  # alpha - edge paths.
     facesTemp = dict()
-    for i,j in product(range(num_rows),range(num_cols)):
+    for i,j in product(range(numrows),range(numcols)):
         #Set of edges associated with face
         tr = 1
         face = set()
-        if faces == num_rows:
-            break  # upper bound on possible no. faces
+        if faces==numrows: break #upper bound on possible no. faces
         # Start position in matrix: returning to this means a face has been
         # enclosed
         io =i
@@ -509,32 +481,39 @@ def edges(M):
             gval = int(M[0,i,j]);
             #current value at index gives next vertex/row
             #value check
-            arr1 = M[0,gval,:] == i%num_rows
-            arr2 = M[1,gval,:] != M[1,i,j] #sign check
+            arr1 = np.where(M[0,gval,:] == i%numrows)
+            arr2 = np.where(M[1,gval,:] != M[1,i,j]) #sign check
+
             i_next = gval
-            alpha = (M[0,i,0]+1)%num_rows
+            alpha = (M[0,i,0]+1)%numrows
             i= i_next
-            new = np.where(arr1 & arr2)[0]
-            #new = np.intersect1d(arr1[0],arr2[0],assume_unique=True)
+
+            new = np.intersect1d(arr1[0],arr2[0],assume_unique=True)
             #ENS: val and sign correct
             ind = np.where(new%2==j%2) #ENS: beta->beta, alpha->alpha
-            j_next = (int(new[ind])+1)%num_cols #Always move clockwise
+            j_next = (int(new[ind])+1)%numcols #Always move clockwise
             j_old = j
             j = j_next
-            if (i,j) in old_vertices:
+            if (i,j) in old_Vertices:
                 break
-            old_vertices.append((i,j))
+            old_Vertices.append((i,j))
             edges += 1
 
-            alpha_new =( M[0,i,0]+1) % num_rows;
+            alpha_new =( M[0,i,0]+1) % numrows;
             shift = (alpha_new - alpha)
 
-            if (shift==1 and j%2 == 1) or (shift == 1-num_rows and alpha_new==0 and j%2==1):
+            if shift==1 and j%2 == 1:
                 face.add(alpha_new)
-                pathTemp.append((alpha_new,(j)%num_cols))
-            elif (shift==-1 and j%2==1 ) or (shift == num_rows-1 and alpha ==0  and j%2==1):
+                pathTemp.append((alpha_new,(j)%numcols))
+            elif shift==-1 and j%2==1:
                 face.add(alpha)
-                pathTemp.append((alpha,(j)%num_cols))
+                pathTemp.append((alpha,(j)%numcols))
+            elif shift == numrows-1 and alpha ==0  and j%2==1: #
+                face.add(alpha)
+                pathTemp.append((alpha,(j)%numcols))
+            elif shift == 1-numrows and alpha_new==0 and j%2==1: #
+                face.add(alpha_new)
+                pathTemp.append((alpha_new,(j)%numcols))
 
             if (i,j)==(io,jo):
                 facesTemp[edges] = facesTemp.get(edges,0) +1
@@ -544,13 +523,10 @@ def edges(M):
                     Paths.append(pathTemp)
                     faces += 1
                     found = 1
-                    all_faces.append((edges,face))
-    #from sys import stderr
-    #stderr.write('all_faces '+str(all_faces)+'\n')
-    #stderr.write('Paths '+str(Paths))
-    return all_faces, Paths
+                    allFaces.append((edges,face))
+    return allFaces, Paths
 
-def boundary_count(M):
+def boundaryCount(M):
     '''
     :param M: the matrix representing a pair of curves
     :type M: numpy.array(dtype=float64) of shape (2,n, 4)
@@ -609,7 +585,7 @@ def boundary_count(M):
                 found = 1 #INV: found = 1 -> has found a bdy curve
     return faces, bigonFlag
 
-def vector_solution(edges):
+def vectorSolution(edges):
 
     solution = dict()
 
@@ -635,7 +611,7 @@ def genus(M, euler=0, boundaries = 0):
 
     '''
     V = M.shape[1] # vertices
-    P, bigon = boundary_count(M)  # Polygons in the complement of curve pair
+    P, bigon = boundaryCount(M) # Polygons in the complement of curve pair
     #if bigon is 1: P -= 1 # pull away one bigon
     #Euler characteristic (since edges = 2*vertices) is P - V
     # originally X = V-E+P
@@ -650,12 +626,13 @@ def genus(M, euler=0, boundaries = 0):
 
     return returnVal[euler]
 
-def test_collection(matrix_list, original_genus):
+
+def testCollection(matrixList, originalGenus):
     '''
-    :param matrix_list:
-    :typematrix_listt: list of numpy.array(dtype=float64)
-    :param original_genus:
-    :typeoriginal_genuss:
+    :param matrixList:
+    :type matrixList: list of numpy.array(dtype=float64)
+    :param originalGenus:
+    :type originalGenus:
     :returns: list of booleans and a dictionary containing the matrices without bigons.
 
     Test a collection of matrices to see if they fill a given genus.
@@ -664,9 +641,9 @@ def test_collection(matrix_list, original_genus):
     genusCollection = []
     index = 0
     matrixLibrary = dict()
-    for M in matrix_list:
+    for M in matrixList:
 
-        bigon = boundary_count(M)[1]
+        bigon = boundaryCount(M)[1]
         Genus = genus(M)
         matrixLibrary[index] = M
         index += 1
@@ -675,7 +652,7 @@ def test_collection(matrix_list, original_genus):
 
         genusCollection.append(Genus)
     # Test if all fill and thus distance g.t. 3
-    test = [Genus == original_genus for Genus in genusCollection]
+    test = [Genus == originalGenus for Genus in genusCollection]
     return test, matrixLibrary
 
 def fourgonTest(F4, Fn):
@@ -693,7 +670,7 @@ def fourgonTest(F4, Fn):
             if len(islandFace[1] & bridgeFace[1]) >= 2: return True
     return False
 
-def Three(M, allPaths, ext=0, originalGenus = False, boundaries = False, edges = False):
+def Three(M, allPaths, ext=0):
     '''
     :param M:
     :type M:
@@ -707,19 +684,12 @@ def Three(M, allPaths, ext=0, originalGenus = False, boundaries = False, edges =
 
     three, matrixLibrary = 0, dict()
 
-    if not originalGenus:
-        originalGenus = genus(M)
-    if not boundaries:
-        F0, bigon = boundary_count(M)
-    else:
-        F0, bigon = boundaries
-    if not edges:
-        #Calculate face alpha edges and alpha edge paths
-        Faces, edgePaths = edges(M)
-    else:
-        Faces, edgePaths = edges
 
-    Bridges, Islands, lengthCheck = face_parse(Faces)
+    F0, bigon = boundaryCount(M)
+    originalGenus = genus(M)
+    #Calculate face alpha edges and alpha edge paths
+    Faces, edgePaths = edges(M)
+    Bridges, Islands, lengthCheck = faceParse(Faces)
 
     # Bridges are faces bounded by four edges.
     # Islands are bounded bt more than four, say six or eight...
@@ -757,7 +727,7 @@ def Three(M, allPaths, ext=0, originalGenus = False, boundaries = False, edges =
     # in the complement which is distance two. Thus the original pair is
     # Distance three.
 
-    if faces_share_two_edges(islandFaces):
+    if facesShareTwoEdges(islandFaces):
         three = 1
     #	print ''' Found two faces that share multiple edges: A curve that
     #			  intersects the non-reference curve only two times has been
@@ -773,9 +743,9 @@ def Three(M, allPaths, ext=0, originalGenus = False, boundaries = False, edges =
     faces += islandFaces
 
     #Build paths into curves and intersect with alpha
-    matrixList = build_matrices(edgePaths, allPaths)
+    matrixList = buildMatrices(edgePaths, allPaths)
 
-    genusTest, matrixLibrary = test_collection(matrixList, originalGenus)
+    genusTest, matrixLibrary = testCollection(matrixList,originalGenus)
     if three != 1:
         three = 1 if False in genusTest else 0
 
@@ -783,28 +753,28 @@ def Three(M, allPaths, ext=0, originalGenus = False, boundaries = False, edges =
     returnVals = [three, matrixLibrary]
     return returnVals
 
-def ladder_convert(ladder_top, ladder_bottom):
+def ladderConvert(ladderTop, ladderBottom):
     #print ladderTop, ladderBottom
-    n = len(ladder_top)
+    n = len(ladderTop)
     newTop = [' ']*n
     newBottom = list(newTop)
 
     for j in range(1, n+1):
 
-        if j in ladder_top and j in ladder_bottom:
-            newTop[ladder_top.index(j)]  = ladder_bottom.index(j)
-            newBottom[ladder_bottom.index(j)] = ladder_top.index(j)
+        if j in ladderTop and j in ladderBottom:
+            newTop[ladderTop.index(j)]  = ladderBottom.index(j)
+            newBottom[ladderBottom.index(j)] = ladderTop.index(j)
 
-        elif j in ladder_top:
-            ladderTopTemp = list(ladder_top)
-            indices = [ladder_top.index(j)]; ladderTopTemp[indices[0]] = None#ladderTopTemp.remove(j)
+        elif j in ladderTop:
+            ladderTopTemp = list(ladderTop)
+            indices = [ladderTop.index(j)]; ladderTopTemp[indices[0]] = None#ladderTopTemp.remove(j)
             indices.append(ladderTopTemp.index(j))
             newTop[indices[0]] = indices[1]
             newTop[indices[1]] = indices[0]
 
-        elif j in ladder_bottom:
-            ladderBottomTemp = list(ladder_bottom)
-            indices = [ladder_bottom.index(j)]; ladderBottomTemp[indices[0]] = None #ladderBottomTemp.remove(j)
+        elif j in ladderBottom:
+            ladderBottomTemp = list(ladderBottom)
+            indices = [ladderBottom.index(j)]; ladderBottomTemp[indices[0]] = None #ladderBottomTemp.remove(j)
             indices.append(ladderBottomTemp.index(j))
             newBottom[indices[0]] = indices[1]
             newBottom[indices[1]] = indices[0]
@@ -889,7 +859,7 @@ def matrix_is_multicurve(beta):
 def test_permutations(original_ladder):
     distance4 = []
     distance3 = []
-    #from curvepair import CurvePair
+    from curvepair import CurvePair
     ladder = deepcopy(original_ladder)
     if not original_ladder is None:
         for i in range(len(ladder[0])):
@@ -930,7 +900,7 @@ def test_perms(original_ladder):
     distance4 = []
     distance3 = []
     ladder_to_perm = deepcopy(original_ladder)
-    #from curvepair import CurvePair
+    from curvepair import CurvePair
     if not original_ladder is None:
         for i in range(len(ladder_to_perm[0])):
             if not ladder_is_multicurve(*ladder_to_perm):
@@ -947,231 +917,3 @@ def test_perms(original_ladder):
             first_vertex = ladder_to_perm[0].pop(0)
             ladder_to_perm[0].append(first_vertex)
     return distance3, distance4
-
-#4+2-3-5-1+
-
-#[1,2,3,2,4]
-#[5,3,4,1,5]
-
-#1-6+4-2+5-7+3+
-
-#[7,4,7,2,4,2,6]
-#[1,3,6,3,5,1,5]
-
-#2+5-7+3+1-6+4-
-
-#[4,1,4,6,1,6,3]
-#[5,7,3,7,2,5,2]
-def ladder_to_cycle(ladder_top, ladder_bottom):
-    locations = {arc: {'top': [], 'bottom': []} for arc in set(ladder_top + ladder_bottom)}
-    for loc, varc in enumerate(ladder_top):
-        locations[varc]['top'].append(loc)
-
-    for loc, varc in enumerate(ladder_bottom):
-        locations[varc]['bottom'].append(loc)
-
-    n = len(ladder_top)
-    cycle = ''
-    #arbitrarily orient them positively
-    orientation = '+'
-    current = 'top'
-    start = 1
-    prev_loc = (ladder_top+ladder_bottom).index(start) % n
-    for i in range(n):
-        #get the top and bottom of the current vertex
-        top = locations[start]['top']
-        bottom = locations[start]['bottom']
-
-        # if there is an endpoint on both the top and bottom,
-        # then orientation is preserved and the location is simply
-        # whatever hasn't already been used. We switch side of the
-        # ladder accordingly
-        if top and bottom:
-            # switch side of ladder
-            current = 'top' if current == 'bottom' else 'bottom'
-            # preserve orientation
-            orientation = '-' if orientation == '-' else '+'
-            # get the locations avaiable there
-            locs = locations[start][current]
-            cycle += str(locs[0]+1) + orientation
-            if current == 'bottom':
-                start = ladder_top[locs[0]]
-            if current == 'top':
-                start = ladder_bottom[locs[0]]
-            prev_loc = locs[0]
-            current = 'top' if current == 'bottom' else 'bottom'
-        elif not top:
-            current = 'bottom'
-            orientation = '-' if orientation == '+' else '+'
-            locs = locations[start][current]
-            t = set(locs)
-            t.remove(prev_loc)
-            current_loc = t.pop()
-            cycle += str(current_loc+1)+orientation
-            start = ladder_top[current_loc]
-            prev_loc = current_loc
-            current = 'top'
-        elif not bottom:
-            current = 'top'
-            orientation = '-' if orientation == '+' else '+'
-            locs = locations[start][current]
-            t = set(locs)
-            t.remove(prev_loc)
-            current_loc = t.pop()
-            cycle += str(current_loc+1)+orientation
-            start = ladder_bottom[current_loc]
-            prev_loc = current_loc
-
-            current = 'bottom'
-    return cycle
-
-
-def cycle_to_ladder(cycle_rep):
-    arcs = [int(i) for i in re.split('[-+]', cycle_rep)[:-1]]
-    n = len(arcs)
-    signs = re.split('[0-9]+', cycle_rep)[1:]
-    top = [0 for i in range(len(arcs))]
-    bottom = [0 for i in range(len(arcs))]
-    ladder = [top, bottom]
-    
-    ladder_index = 0
-    for i in range(1, len(arcs)+1):
-        current_sign = signs.pop(0)
-        current_v = arcs.pop(0)
-        if current_sign == '+':
-            ladder[0][current_v-1] = i 
-            if i == 1:
-                ladder[1][current_v-1] = n#((i - 2) % n)
-            else:
-                ladder[1][current_v-1] = ((i - 1) % n)
-
-        if current_sign == '-':
-            ladder[1][current_v-1] = i 
-            if i == 1:
-                ladder[0][current_v-1] = n#((i - 2) % n)
-            else:
-                ladder[0][current_v-1] = ((i - 1) % n)
-
-
-    return ladder
-
-
-#import numpy as np
-#from curves import fix_matrix_signs, boundary_count, genus, ladder_convert, vector_solution, edges, Three
-from graph import Graph
-
-
-class CurvePair:
-    '''
-    ladder = None
-    beta = None
-    top = []
-    bottom = []
-    n = 0
-    matrix = None
-    boundaries = None
-    genus = None
-    edges = None
-
-    solution = None
-    distance = 0
-    loops = []
-    '''
-    def __init__(self, top_beta, bottom_beta, dist=1, conjectured_dist=3,recursive=False):
-
-        is_ladder = lambda top, bottom: not (0 in top or 0 in bottom)
-
-        if is_ladder(top_beta, bottom_beta):
-            self.ladder = [top_beta, bottom_beta]
-        else:
-            self.ladder = None
-
-        if is_ladder(top_beta, bottom_beta):
-            self.beta = ladder_convert(top_beta, bottom_beta)
-            self.top = self.beta[0]
-            self.bottom = self.beta[1]
-        else:
-            self.top = top_beta
-            self.bottom = bottom_beta
-            self.beta = [self.top, self.bottom]
-
-        self.n = len(self.top)
-
-        self.matrix = np.zeros((2,self.n,4))
-        self.matrix[0,:,0] = [self.n-1] + range(self.n-1)
-        self.matrix[0,:,1] = self.top
-        self.matrix[0,:,2] = range(1,self.n) +[0]
-        self.matrix[0,:,3] = self.bottom
-
-        self.matrix = fix_matrix_signs(self.matrix)
-
-        self.boundaries = boundary_count(self.matrix)
-        self.genus = genus(self.matrix)
-        self.edges = edges(self.matrix)
-        #self.arc_boundary = self.edges[1]
-        self.solution = vector_solution(self.edges[0])
-
-        self.loops = []
-        self.dist = dist
-        self.conjectured_dist = conjectured_dist
-        self.computed_distance = False
-        self.recursive = recursive
-    
-    @property
-    def distance(self):
-        if self.computed_distance == False:
-            if self.dist is 1:
-                graph = Graph(self.edges, rep_num=self.conjectured_dist-2)
-                graph.compute_loops(self.n, self.genus)
-                self.loops = graph.gammas
-                #stderr.write(str(self.loops)+'\n')
-                self.computed_distance, self.loop_matrices = self.compute_distance(self.matrix, self.loops, recursive=self.recursive)
-
-            else:
-                self.computed_distance = None
-            return self.computed_distance
-        else:
-            return self.computed_distance
-
-
-    def __repr__(self):
-        return str(self.ladder[0])+'\n'+str(self.ladder[1])+'\n'
-
-    def compute_distance(self, M, all_paths,recursive=True):
-        '''
-        :param M: the matrix
-        :type M:
-        :param all_paths:
-        :type all_paths:
-        :returns: dist: the distance if three/four, or 'Higher' if dist is > 4.
-
-        Computes the distance between the two curves embedded in the matrix.
-        If this distance is three, tries to use simple paths to extend the distance
-        in a different direction. If this fails, simply returns three;
-        else it prints a curve that is distance four from alpha.
-
-        '''
-
-        dist_is_three, lib = Three(M, all_paths, originalGenus=self.genus, boundaries=self.boundaries, edges=self.edges)
-        dist = 3 if dist_is_three  else 'at least 4!'
-        if dist == 3:
-            return dist, lib
-        else:
-            if recursive:
-                geodesic_distances = []
-                for k, matrix in lib.iteritems():
-                    #stderr.write(str(matrix))
-                    if np.array_equal(matrix, self.matrix):
-                        continue
-                    elif self.solution == CurvePair(matrix[0, :, 1], matrix[0, :, 3],0).solution \
-                            and len(self.matrix[0]) == len(matrix[0]):
-                        continue
-                    cc = CurvePair(matrix[0, :, 1], matrix[0, :, 3])
-                    #stderr.write(str(k)+": "+str(cc.distance)+'\n')
-                    geodesic_distances.append(cc.distance)
-                    #print 'computed curve',k,'!'
-                #print '\n'
-                return min(set(geodesic_distances)) + 1, lib
-            else:
-                return dist, lib
-
